# ============================================================
#
# Copyright (C) 2012 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
#
# This file may be licensed under the terms of the
# GNU Lesser General Public License Version 3 (the ``LGPL''),
# or (at your option) any later version.
#
# Software distributed under the License is distributed
# on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
# express or implied. See the LGPL for the specific language
# governing rights and limitations.
#
# You should have received a copy of the LGPL along with this
# program. If not, go to http://www.gnu.org/licenses/lgpl.html
# or write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# The development of this software was supported by:
#   CoR-Lab, Research Institute for Cognition and Robotics
#     Bielefeld University
#
# ============================================================

"""
A module with exemplary functions implementing standalone executables for the
exemplary python code.

@author: jwienke
"""

from buildsystemessentials import MagicNumberTransformer

# mark-start::show-for-parsing
def sendMagicNumber():
    
    from rsb import createInformer, Scope
    import argparse
    
    parser = argparse.ArgumentParser(description='An example program sending some magic numbers')
    parser.add_argument('--magicnumber', type=int, required=True,
                        help='magic number to transform and send')
    parser.add_argument('--scope', type=str, default='/an/example',
                        help='scope to send on')
    args = parser.parse_args()

    # create an informer for integers
    informer = createInformer(args.scope, dataType=int)

    # send some events using a method that directly accepts data
    informer.publishData(MagicNumberTransformer().transform(args.magicnumber))

    informer.deactivate()
# mark-end::show-for-parsing
